@@ -347,13 +347,19 @@ var _ = Describe("Generating fluentd config", func() {
 					remove_keys req,res,msg,name,level,v,pid,err
 				</filter>
 				<filter k8s-audit.log**>
-					@type record_transformer
-					enable_ruby
-					<record>
-						k8s_audit_level ${record['level']}
-						level info
-					</record>
-			  </filter>
+				  @type record_modifier
+				  <record>
+					k8s_audit_level ${record['level']}
+					level info
+				  </record>
+				</filter>
+				<filter openshift-audit.log**>
+				  @type record_modifier
+				  <record>
+					openshift_audit_level ${record['level']}
+					level info
+				  </record>
+				</filter>				
 				<filter **>
 					@type viaq_data_model
 					elasticsearch_index_prefix_field 'viaq_index_name'
@@ -765,13 +771,19 @@ var _ = Describe("Generating fluentd config", func() {
 					remove_keys req,res,msg,name,level,v,pid,err
 				</filter>
 				<filter k8s-audit.log**>
-					@type record_transformer
-					enable_ruby
-					<record>
-						k8s_audit_level ${record['level']}
-						level info
-					</record>
+				  @type record_modifier
+				  <record>
+					k8s_audit_level ${record['level']}
+					level info
+				  </record>
 				</filter>
+				<filter openshift-audit.log**>
+				  @type record_modifier
+				  <record>
+					openshift_audit_level ${record['level']}
+					level info
+				  </record>
+				</filter>				
 				<filter **>
 					@type viaq_data_model
 					elasticsearch_index_prefix_field 'viaq_index_name'
