@@ -209,13 +209,19 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
   </filter>
 
   <filter k8s-audit.log**>
-    @type record_transformer
-    enable_ruby
+    @type record_modifier
     <record>
       k8s_audit_level ${record['level']}
       level info
     </record>
   </filter>
+  <filter openshift-audit.log**>
+    @type record_modifier
+    <record>
+      openshift_audit_level ${record['level']}
+      level info
+    </record>
+  </filter>
 
   <filter **>
     @type viaq_data_model
@@ -476,18 +482,6 @@ const sourceToPipelineCopyTemplate = `{{- define "sourceToPipelineCopyTemplate"
       @type relabel
       @label {{labelName $pipelineLabel}}
     </store>
-{{- end }}
-{{ if .IncludeLegacySecureForward }}
-    <store>
-      @type relabel
-      @label @_LEGACY_SECUREFORWARD
-    </store>
-{{- end }}
-{{ if .IncludeLegacySyslog }}
-    <store>
-      @type relabel
-      @label @_LEGACY_SYSLOG
-    </store>
 {{- end }}
   </match>
 </label>
