@@ -10,8 +10,8 @@ import (
 func ReconcileCollector(requestCluster *logging.ClusterLogging, collector *collector.CollectorSpec, requestClient client.Client) (err error) {
 	logger.Debugf("Reconciling collector: %v", collector)
 	clusterRequest := ClusterLoggingRequest{
-		client:            requestClient,
-		cluster:           requestCluster,
+		Client:            requestClient,
+		Cluster:           requestCluster,
 		ForwardingRequest: nil,
 		Collector:         collector,
 	}
